@@ -1,4 +1,12 @@
-from pynumaflow.function._dtypes import Message, Messages, Datum, IntervalWindow, Metadata
+from pynumaflow.function._dtypes import (
+    Message,
+    Messages,
+    Datum,
+    IntervalWindow,
+    Metadata,
+    ALL,
+    DROP,
+)
 from pynumaflow.function.server import UserDefinedFunctionServicer
 
 __all__ = [
@@ -8,4 +16,6 @@ __all__ = [
     "IntervalWindow",
     "Metadata",
     "UserDefinedFunctionServicer",
+    "ALL",
+    "DROP",
 ]
