@@ -7,7 +7,7 @@ from google.protobuf import timestamp_pb2 as _timestamp_pb2
 from grpc import StatusCode
 from grpc_testing import server_from_dictionary, strict_real_time
 
-from pynumaflow._constants import DATUM_KEY, WIN_START_TIME, WIN_END_TIME
+from pynumaflow._constants import DATUM_KEY
 from pynumaflow.function import (
     Message,
     Messages,
@@ -32,10 +32,10 @@ def map_handler(key: str, datum: Datum) -> Messages:
     return messages
 
 
-def reduce_handler(key: str, datums: Iterator[Datum], md: Metadata) -> Messages:
+async def reduce_handler(key: str, datums: Iterator[Datum], md: Metadata) -> Messages:
     interval_window = md.interval_window
     counter = 0
-    for _ in datums:
+    async for _ in datums:
         counter += 1
     msg = (
         f"counter:{counter} interval_window_start:{interval_window.start} "
@@ -68,11 +68,11 @@ def mock_watermark():
 
 
 def mock_interval_window_start():
-    return 1662998400
+    return 1662998400000
 
 
 def mock_interval_window_end():
-    return 1662998460
+    return 1662998460000
 
 
 class TestServer(unittest.TestCase):
@@ -187,96 +187,11 @@ class TestServer(unittest.TestCase):
         )
         self.assertEqual(code, StatusCode.OK)
 
-    def test_reduce_counter(self):
-        event_time_timestamp = _timestamp_pb2.Timestamp()
-        event_time_timestamp.FromDatetime(dt=mock_event_time())
-        watermark_timestamp = _timestamp_pb2.Timestamp()
-        watermark_timestamp.FromDatetime(dt=mock_watermark())
-
-        request = udfunction_pb2.Datum(
-            value=mock_message(),
-            event_time=udfunction_pb2.EventTime(event_time=event_time_timestamp),
-            watermark=udfunction_pb2.Watermark(watermark=watermark_timestamp),
-        )
-
-        rpc = self.test_server.invoke_stream_unary(
-            method_descriptor=(
-                udfunction_pb2.DESCRIPTOR.services_by_name["UserDefinedFunction"].methods_by_name[
-                    "ReduceFn"
-                ]
-            ),
-            invocation_metadata={
-                (DATUM_KEY, "test"),
-                (WIN_START_TIME, mock_interval_window_start()),
-                (WIN_END_TIME, mock_interval_window_end()),
-            },
-            timeout=1,
-        )
-
-        for _ in range(10):
-            rpc.send_request(request)
-        rpc.requests_closed()
-
-        response, metadata, code, details = rpc.termination()
-        self.assertEqual(1, len(response.elements))
-        self.assertEqual(code, StatusCode.OK)
-        self.assertEqual(
-            bytes(
-                "counter:10 interval_window_start:2022-09-12 16:00:00+00:00 "
-                "interval_window_end:2022-09-12 16:01:00+00:00",
-                encoding="utf-8",
-            ),
-            response.elements[0].value,
-        )
-
-    def test_udf_reduce_err(self):
-        my_servicer = UserDefinedFunctionServicer(reduce_handler=err_reduce_handler)
-        services = {udfunction_pb2.DESCRIPTOR.services_by_name["UserDefinedFunction"]: my_servicer}
-        self.test_server = server_from_dictionary(services, strict_real_time())
-
-        event_time_timestamp = _timestamp_pb2.Timestamp()
-        event_time_timestamp.FromDatetime(dt=mock_event_time())
-        watermark_timestamp = _timestamp_pb2.Timestamp()
-        watermark_timestamp.FromDatetime(dt=mock_watermark())
-
-        request = udfunction_pb2.Datum(
-            value=mock_message(),
-            event_time=udfunction_pb2.EventTime(event_time=event_time_timestamp),
-            watermark=udfunction_pb2.Watermark(watermark=watermark_timestamp),
-        )
-
-        rpc = self.test_server.invoke_stream_unary(
-            method_descriptor=(
-                udfunction_pb2.DESCRIPTOR.services_by_name["UserDefinedFunction"].methods_by_name[
-                    "ReduceFn"
-                ]
-            ),
-            invocation_metadata={
-                (DATUM_KEY, "test"),
-                (WIN_START_TIME, mock_interval_window_start()),
-                (WIN_END_TIME, mock_interval_window_end()),
-                ("IMPROVE_CODECOV", "this metadata aims to improve the codecov"),
-            },
-            timeout=1,
-        )
-
-        for _ in range(10):
-            rpc.send_request(request)
-        rpc.requests_closed()
-
-        response, metadata, code, details = rpc.termination()
-        self.assertEqual(1, len(response.elements))
-        self.assertEqual(DROP.decode(), response.elements[0].key)
-        self.assertEqual(
-            b"",
-            response.elements[0].value,
-        )
-
     def test_invalid_input(self):
         with self.assertRaises(ValueError):
             UserDefinedFunctionServicer()
 
-    def test_invalid_reduce_metadata(self):
+    def test_invalid_reduce_metadata(self) -> None:
         try:
             _ = self.test_server.invoke_stream_unary(
                 method_descriptor=(
